# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

import helloworld_pb2 as helloworld__pb2


class GreeterStub(object):
    """The greeting service definition.
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.SayHello = channel.unary_unary(
                '/helloworld.Greeter/SayHello',
                request_serializer=helloworld__pb2.HelloRequest.SerializeToString,
                response_deserializer=helloworld__pb2.HelloReply.FromString,
                )
        self.GetGreeter = channel.unary_unary(
                '/helloworld.Greeter/GetGreeter',
                request_serializer=helloworld__pb2.GetRequest.SerializeToString,
                response_deserializer=helloworld__pb2.ItemResponse.FromString,
                )
        self.ListGreeter = channel.unary_unary(
                '/helloworld.Greeter/ListGreeter',
                request_serializer=helloworld__pb2.ListRequest.SerializeToString,
                response_deserializer=helloworld__pb2.ListResponse.FromString,
                )
        self.CreateGreeter = channel.unary_unary(
                '/helloworld.Greeter/CreateGreeter',
                request_serializer=helloworld__pb2.CreateRequest.SerializeToString,
                response_deserializer=helloworld__pb2.ItemResponse.FromString,
                )
        self.GetItem = channel.unary_unary(
                '/helloworld.Greeter/GetItem',
                request_serializer=helloworld__pb2.GetRequest.SerializeToString,
                response_deserializer=helloworld__pb2.ItemResponse.FromString,
                )
        self.ListItems = channel.unary_unary(
                '/helloworld.Greeter/ListItems',
                request_serializer=helloworld__pb2.ListRequest.SerializeToString,
                response_deserializer=helloworld__pb2.ListResponse.FromString,
                )
        self.CreateItem = channel.unary_unary(
                '/helloworld.Greeter/CreateItem',
                request_serializer=helloworld__pb2.CreateRequest.SerializeToString,
                response_deserializer=helloworld__pb2.ItemResponse.FromString,
                )


class GreeterServicer(object):
    """The greeting service definition.
    """

    def SayHello(self, request, context):
        """Sends a greeting
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetGreeter(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListGreeter(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateGreeter(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetItem(self, request, context):
        """item resource
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListItems(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateItem(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_GreeterServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'SayHello': grpc.unary_unary_rpc_method_handler(
                    servicer.SayHello,
                    request_deserializer=helloworld__pb2.HelloRequest.FromString,
                    response_serializer=helloworld__pb2.HelloReply.SerializeToString,
            ),
            'GetGreeter': grpc.unary_unary_rpc_method_handler(
                    servicer.GetGreeter,
                    request_deserializer=helloworld__pb2.GetRequest.FromString,
                    response_serializer=helloworld__pb2.ItemResponse.SerializeToString,
            ),
            'ListGreeter': grpc.unary_unary_rpc_method_handler(
                    servicer.ListGreeter,
                    request_deserializer=helloworld__pb2.ListRequest.FromString,
                    response_serializer=helloworld__pb2.ListResponse.SerializeToString,
            ),
            'CreateGreeter': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateGreeter,
                    request_deserializer=helloworld__pb2.CreateRequest.FromString,
                    response_serializer=helloworld__pb2.ItemResponse.SerializeToString,
            ),
            'GetItem': grpc.unary_unary_rpc_method_handler(
                    servicer.GetItem,
                    request_deserializer=helloworld__pb2.GetRequest.FromString,
                    response_serializer=helloworld__pb2.ItemResponse.SerializeToString,
            ),
            'ListItems': grpc.unary_unary_rpc_method_handler(
                    servicer.ListItems,
                    request_deserializer=helloworld__pb2.ListRequest.FromString,
                    response_serializer=helloworld__pb2.ListResponse.SerializeToString,
            ),
            'CreateItem': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateItem,
                    request_deserializer=helloworld__pb2.CreateRequest.FromString,
                    response_serializer=helloworld__pb2.ItemResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'helloworld.Greeter', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class Greeter(object):
    """The greeting service definition.
    """

    @staticmethod
    def SayHello(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/helloworld.Greeter/SayHello',
            helloworld__pb2.HelloRequest.SerializeToString,
            helloworld__pb2.HelloReply.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetGreeter(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/helloworld.Greeter/GetGreeter',
            helloworld__pb2.GetRequest.SerializeToString,
            helloworld__pb2.ItemResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListGreeter(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/helloworld.Greeter/ListGreeter',
            helloworld__pb2.ListRequest.SerializeToString,
            helloworld__pb2.ListResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CreateGreeter(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/helloworld.Greeter/CreateGreeter',
            helloworld__pb2.CreateRequest.SerializeToString,
            helloworld__pb2.ItemResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetItem(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/helloworld.Greeter/GetItem',
            helloworld__pb2.GetRequest.SerializeToString,
            helloworld__pb2.ItemResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListItems(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/helloworld.Greeter/ListItems',
            helloworld__pb2.ListRequest.SerializeToString,
            helloworld__pb2.ListResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CreateItem(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/helloworld.Greeter/CreateItem',
            helloworld__pb2.CreateRequest.SerializeToString,
            helloworld__pb2.ItemResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)
